pub struct ModelFlags(/* private fields */);Implementations
Sourceimpl ModelFlags
impl ModelFlags
pub const AUTOGENERATED_HITBOX: Self
pub const USES_ENV_CUBEMAP: Self
pub const FORCE_OPAQUE: Self
pub const TRANSLUCENT_TWOPASS: Self
pub const STATIC_PROP: Self
pub const USES_FB_TEXTURE: Self
pub const HASSHADOWLOD: Self
pub const USES_BUMPMAPPING: Self
pub const USE_SHADOWLOD_MATERIALS: Self
pub const OBSOLETE: Self
pub const UNUSED: Self
pub const NO_FORCED_FADE: Self
pub const FORCE_PHONEME_CROSSFADE: Self
pub const CONSTANT_DIRECTIONAL_LIGHT_DOT: Self
pub const FLEXES_CONVERTED: Self
pub const BUILT_IN_PREVIEW_MODE: Self
pub const AMBIENT_BOOST: Self
pub const DO_NOT_CAST_SHADOWS: Self
pub const CAST_TEXTURE_SHADOWS: Self
pub const VERT_ANIM_FIXED_POINT_SCALE: Self
Sourceimpl ModelFlags
impl ModelFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ModelFlags
impl ModelFlags
Sourcepub const fn iter(&self) -> Iter<ModelFlags>
pub const fn iter(&self) -> Iter<ModelFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ModelFlags>
pub const fn iter_names(&self) -> IterNames<ModelFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.